@@ -1,10 +1,12 @@
 #added the coarse option (defaulting to TRUE)  8/25/23
+#added the dof parameter (passed from cfa)   12/1/25
+
 "factor.stats" <- 
-function(r=NULL,f,phi=NULL,n.obs=NA,np.obs=NULL,alpha=.1,fm=NULL,smooth=TRUE, coarse=TRUE) {
-   fa.stats(r=r,f=f,phi=phi,n.obs=n.obs,np.obs=np.obs,alpha=alpha,fm=fm,smooth=smooth,coarse=coarse)}
+function(r=NULL,f,phi=NULL,n.obs=NA,np.obs=NULL,alpha=.1,fm=NULL,smooth=TRUE, coarse=TRUE, dof=NULL) {
+   fa.stats(r=r,f=f,phi=phi,n.obs=n.obs,np.obs=np.obs,alpha=alpha,fm=fm,smooth=smooth,coarse=coarse, dof=dof)}
 
 "fa.stats" <- 
-function(r=NULL,f,phi=NULL,n.obs=NA,np.obs=NULL,alpha=.05,fm=NULL,smooth=TRUE,coarse=TRUE) {
+function(r=NULL,f,phi=NULL,n.obs=NA,np.obs=NULL,alpha=.05,fm=NULL,smooth=TRUE,coarse=TRUE, dof=NULL) {
 #revised June 21, 2010 to add RMSEA etc. 
 #revised August 25, 2011 to add cor.smooth for smoothing
 #revised November 10, 2012 to add stats for the minchi option of factoring
@@ -33,8 +35,9 @@ conf.level <- alpha
     r2 <- sum(r*r)
     rstar2 <- sum(residual*residual)
     result <- list(residual = residual)
- 
-    result$dof <- dof <-  n * (n-1)/2 - n * nfactors + (nfactors *(nfactors-1)/2)
+  if(is.null(dof)){
+    result$dof <- dof <-  n * (n-1)/2 - n * nfactors + (nfactors *(nfactors-1)/2)} else { #for exploratory
+       result$dof <- dof } #for confirmatory 
     #r2.off <- r
     #diag(r2.off) <- 0
    # r2.off <- sum(r2.off^2)
@@ -93,7 +96,7 @@ conf.level <- alpha
             m.inv.r <- diag(1,n,n)}
     if(is.na(n.obs)) {result$n.obs=NA 
     			      result$PVAL=NA} else {result$n.obs=n.obs}
-    result$dof <-  n * (n-1)/2 - n * nfactors + (nfactors *(nfactors-1)/2)
+   # result$dof <-  n * (n-1)/2 - n * nfactors + (nfactors *(nfactors-1)/2)
     result$objective <- sum(diag((m.inv.r))) - log(det(m.inv.r)) -n   #this is what Tucker Lewis call F
     if(is.infinite(result$objective)) {result$objective <- rstar2
                                        message("The determinant of the smoothed correlation was zero.\nThis means the objective function is not defined.\nChi square is based upon observed residuals.")}
