@@ -140,13 +140,16 @@ if(scores) {
      item.means <- colMeans(items,na.rm=TRUE)
     if (is.null(min)) {min <- min(items,na.rm=TRUE)}
     if (is.null(max)) {max <- max(items,na.rm=TRUE)}
+    browser()
 if(impute !="none") {
-        miss <- which(is.na(items),arr.ind=TRUE)
+        miss <- which(is.na(items),arr.ind=TRUE) 
+        if(length(miss>0)) {  #added this 11/14/25 incase there are no missing to impute
         if(impute=="mean") {
        		item.means <- colMeans(items,na.rm=TRUE)   #replace missing values with means
        		items[miss]<- item.means[miss[,2]]} else { 
        		item.med   <- apply(items,2,median,na.rm=TRUE) #replace missing with medians
         	items[miss]<- item.med[miss[,2]]}   #this only works if items is a matrix
+        	}  #we have no missing 
         	items <- as.matrix(items)   #added 11/14/25
         	 scores <- items %*%  keys  #this actually does all the work but doesn't handle missing values
         	C <- cov(items,use="pairwise")
